bayespy.inference.vmp.nodes.deterministic.Deterministic.plates_multiplier
=========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. autoattribute:: Deterministic.plates_multiplier